@@ -13,13 +13,23 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-from multiprocessing.util import spawnv_passfds as _spawnv_passfd
+from gevent.os import _watch_child
+from gevent.threading import local
+from multiprocessing.util import spawnv_passfds as _spawnv_passfd, register_after_fork
 
-from gevent.hub import _get_hub_noargs as get_hub
-
-__implements__ = ["spawnv_passfds"]
+__implements__ = ["spawnv_passfds", "ForkAwareLocal"]
 __target__ = "multiprocessing.util"
 
 
 def spawnv_passfds(path, args, passfds):
-    return get_hub().threadpool.apply(_spawnv_passfd, (path, args, passfds))
+    cpid = _spawnv_passfd(path, args, passfds)
+    _watch_child(cpid)
+    return cpid
+
+
+class ForkAwareLocal(local):
+    def __init__(self):
+        register_after_fork(self, lambda obj: obj.__dict__.clear())
+
+    def __reduce__(self):
+        return type(self), ()
